@@ -1,4 +1,4 @@
-;;; ef-autumn-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-autumn-theme.el --- Legible dark theme with warm, varied colors (red, yellow, green, teal) -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-autumn "Legible dark theme.")
+  (deftheme ef-autumn "Legible dark theme with warm, varied colors (red, yellow, green, teal).")
 
   (defconst ef-autumn-palette
     '(;; Basic tones
@@ -85,6 +85,13 @@
       (bg-magenta  "#c040cf")
       (bg-cyan     "#027080")
 
+      (bg-red-subtle      "#77002a")
+      (bg-green-subtle    "#00422a")
+      (bg-yellow-subtle   "#693200")
+      (bg-blue-subtle     "#242679")
+      (bg-magenta-subtle  "#611062")
+      (bg-cyan-subtle     "#004065")
+
       ;; Diffs
       (bg-added          "#172c0f")
       (bg-added-faint    "#0a1f00")
@@ -129,6 +136,10 @@
       (cursor        "#ffaa33")
       (fg-intense    "#ffffff")
 
+      (modeline-err     "#ff9fbf")
+      (modeline-warning "#dfcf33")
+      (modeline-info    "#4fdf5f")
+
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
@@ -139,6 +150,7 @@
       (date yellow-cooler)
       (name green-warmer)
       (keybind red-warmer)
+      (prompt cyan-cooler)
 
       (builtin red-cooler)
       (comment yellow-faint)
