@@ -1,4 +1,4 @@
-;;; ef-dark-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-dark-theme.el --- Legible dark theme with blue, magenta, cyan, purple colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-dark "Legible dark theme.")
+  (deftheme ef-dark "Legible dark theme with blue, magenta, cyan, purple colors.")
 
   (defconst ef-dark-palette
     '(;; Basic tones
@@ -85,6 +85,13 @@
       (bg-magenta  "#c040cf")
       (bg-cyan     "#2270be")
 
+      (bg-red-subtle      "#72002a")
+      (bg-green-subtle    "#00422a")
+      (bg-yellow-subtle   "#603000")
+      (bg-blue-subtle     "#242679")
+      (bg-magenta-subtle  "#5a105f")
+      (bg-cyan-subtle     "#004065")
+
       ;; Diffs
       (bg-added          "#00331f")
       (bg-added-faint    "#002410")
@@ -129,6 +136,10 @@
       (cursor        "#ff66ff")
       (fg-intense    "#ffffff")
 
+      (modeline-err     "#ff80af")
+      (modeline-warning "#dfcf33")
+      (modeline-info    "#2fc82f")
+
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
@@ -136,9 +147,10 @@
 
       (link cyan)
       (link-alt magenta)
-      (date cyan)
+      (date green-cooler)
       (name blue-warmer)
       (keybind blue-cooler)
+      (prompt green-cooler)
 
       (builtin magenta)
       (comment yellow-faint)
