@@ -1,4 +1,4 @@
-;;; ef-day-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-day-theme.el --- Legible light theme with warm, varied colors (yellow, red, green, purple) -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-day "Legible light theme.")
+  (deftheme ef-day "Legible light theme with warm, varied colors (yellow, red, green, purple).")
 
   (defconst ef-day-palette
     '(;; Basic tones
@@ -85,6 +85,13 @@
       (bg-magenta  "#ff9fee")
       (bg-cyan     "#88cfd0")
 
+      (bg-red-subtle      "#ffc6bf")
+      (bg-green-subtle    "#c4f2af")
+      (bg-yellow-subtle   "#f0f07f")
+      (bg-blue-subtle     "#ccdfff")
+      (bg-magenta-subtle  "#fad3ff")
+      (bg-cyan-subtle     "#bfefff")
+
       ;; Diffs
       (bg-added          "#ccefcf")
       (bg-added-faint    "#e0f3e0")
@@ -129,6 +136,10 @@
       (cursor        "#cf1f00")
       (fg-intense    "#000000")
 
+      (modeline-err     "#900000")
+      (modeline-warning "#66008f")
+      (modeline-info    "#1f409f")
+
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
@@ -139,6 +150,7 @@
       (date cyan-cooler)
       (name yellow)
       (keybind red-warmer)
+      (prompt yellow)
 
       (builtin red-cooler)
       (comment green-faint)
