@@ -88,6 +88,13 @@
       (bg-magenta  "#8040cf")
       (bg-cyan     "#00709e")
 
+      (bg-red-subtle      "#72002a")
+      (bg-green-subtle    "#00422a")
+      (bg-yellow-subtle   "#603000")
+      (bg-blue-subtle     "#242679")
+      (bg-magenta-subtle  "#5a105f")
+      (bg-cyan-subtle     "#004065")
+
       ;; Diffs
       (bg-added          "#00234f")
       (bg-added-faint    "#00143f")
@@ -132,6 +139,10 @@
       (cursor        "#ffff00")
       (fg-intense    "#ffffff")
 
+      (modeline-err     "#ffff00")
+      (modeline-warning "#ddb300")
+      (modeline-info    "#aaaaff")
+
       ;; Mappings
       (err yellow-warmer)
       (warning yellow)
@@ -142,13 +153,14 @@
       (date yellow-cooler)
       (name blue-warmer)
       (keybind yellow-warmer)
+      (prompt yellow)
 
       (builtin blue-warmer)
       (comment yellow-faint)
       (constant blue-cooler)
       (fnname yellow-cooler)
       (keyword yellow-warmer)
-      (preprocessor green-cooler)
+      (preprocessor yellow)
       (docstring cyan-faint)
       (string blue)
       (type magenta-cooler)
