@@ -1,4 +1,4 @@
-;;; ef-spring-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-spring-theme.el --- Legible light theme with cool, varied colors (green, cyan, red) -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-spring "Legible light theme.")
+  (deftheme ef-spring "Legible light theme with cool, varied colors (green, cyan, red).")
 
   (defconst ef-spring-palette
     '(;; Basic tones
@@ -85,6 +85,13 @@
       (bg-magenta  "#ff90fe")
       (bg-cyan     "#88cfe0")
 
+      (bg-red-subtle      "#ffcfbf")
+      (bg-green-subtle    "#afffbf")
+      (bg-yellow-subtle   "#fff576")
+      (bg-blue-subtle     "#ccdfff")
+      (bg-magenta-subtle  "#ffddff")
+      (bg-cyan-subtle     "#bfefff")
+
       ;; Diffs
       (bg-added          "#dfffe0")
       (bg-added-faint    "#e0ffea")
@@ -126,9 +133,13 @@
       (bg-info       "#ccf5dd") ; check with info
 
       (border        "#b4c4c0")
-      (cursor        "#bf0040")
+      (cursor        "#bf005f")
       (fg-intense    "#000000")
 
+      (modeline-err     "#9f0030")
+      (modeline-warning "#5f0f9f")
+      (modeline-info    "#1240af")
+
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
@@ -139,6 +150,7 @@
       (date cyan)
       (name green-cooler)
       (keybind magenta-warmer)
+      (prompt green)
 
       (builtin green)
       (comment yellow-faint)
