@@ -1,4 +1,4 @@
-;;; ef-summer-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-summer-theme.el --- Legible light theme with magenta, purple, gold, cyan colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-summer "Legible light theme.")
+  (deftheme ef-summer "Legible light theme with magenta, purple, gold, cyan colors.")
 
   (defconst ef-summer-palette
     '(;; Basic tones
@@ -85,6 +85,13 @@
       (bg-magenta  "#ff9fee")
       (bg-cyan     "#88ccff")
 
+      (bg-red-subtle      "#ffc3bf")
+      (bg-green-subtle    "#b9f2c6")
+      (bg-yellow-subtle   "#fff576")
+      (bg-blue-subtle     "#ccdfff")
+      (bg-magenta-subtle  "#ffcdff")
+      (bg-cyan-subtle     "#bfeaff")
+
       ;; Diffs
       (bg-added          "#caf4da")
       (bg-added-faint    "#dff6ea")
@@ -129,6 +136,10 @@
       (cursor        "#cf0090")
       (fg-intense    "#000000")
 
+      (modeline-err     "#9f003f")
+      (modeline-warning "#5f009f")
+      (modeline-info    "#1240af")
+
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
@@ -139,6 +150,7 @@
       (date cyan-cooler)
       (name magenta-warmer)
       (keybind red-cooler)
+      (prompt magenta-warmer)
 
       (builtin magenta)
       (comment yellow-faint)
