@@ -6,7 +6,7 @@
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/ef-themes
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
-;; Version: 0.4.2
+;; Version: 0.5.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -54,6 +54,8 @@
     ef-day
     ef-deuteranopia-dark
     ef-deuteranopia-light
+    ef-duo-dark
+    ef-duo-light
     ef-light
     ef-night
     ef-spring
@@ -62,11 +64,11 @@
   "Symbols of all the Ef themes.")
 
 (defconst ef-themes-light-themes
-  '(ef-day ef-light ef-spring ef-summer ef-deuteranopia-light)
+  '(ef-day ef-deuteranopia-light ef-duo-light ef-light ef-spring ef-summer)
   "List of symbols with the light Ef themes.")
 
 (defconst ef-themes-dark-themes
-  '(ef-autumn ef-dark ef-night ef-winter ef-deuteranopia-dark)
+  '(ef-autumn ef-dark ef-deuteranopia-dark ef-duo-dark ef-night ef-winter)
   "List of symbols with the dark Ef themes.")
 
 (defcustom ef-themes-post-load-hook nil
@@ -334,12 +336,14 @@ sequence given SEQ-PRED, using SEQ-DEFAULT as a fallback."
 
 (defvar ef-themes--select-theme-history nil)
 
-(defun ef-themes--select-prompt ()
-  "Minibuffer prompt for `ef-themes-select'."
-  (completing-read "Select Ef Theme: "
-                   (ef-themes--list-known-themes)
-                   nil t nil
-                   'ef-themes--select-theme-history))
+(defun ef-themes--select-prompt (&optional prompt)
+  "Minibuffer prompt for `ef-themes-select'.
+With optional PROMPT string, use it.  Else use a generic prompt."
+  (intern
+   (completing-read (or prompt "Select Ef Theme: ")
+                    (ef-themes--list-known-themes)
+                    nil t nil
+                    'ef-themes--select-theme-history)))
 
 (defun ef-themes--load-theme (theme)
   "Load THEME while disabling other Ef themes.
@@ -352,7 +356,7 @@ Run `ef-themes-post-load-hook'."
 (defun ef-themes-select (theme)
   "Load an Ef THEME using minibuffer completion.
 When called from Lisp, THEME is a symbol."
-  (interactive (list (intern (ef-themes--select-prompt))))
+  (interactive (list (ef-themes--select-prompt)))
   (ef-themes--load-theme theme))
 
 (defun ef-themes--toggle-theme-p ()
@@ -365,16 +369,22 @@ When called from Lisp, THEME is a symbol."
 
 ;;;###autoload
 (defun ef-themes-toggle ()
-  "Toggle between the two `ef-themes-to-toggle'."
+  "Toggle between the two `ef-themes-to-toggle'.
+If `ef-themes-to-toggle' does not specify two Ef themes, inform
+the user about it while prompting with completion for a theme
+among our collection (this is practically the same as the
+`ef-themes-select' command)."
   (interactive)
-  (when-let* ((themes (ef-themes--toggle-theme-p))
-              (one (car themes))
-              (two (cadr themes)))
-    (unless (eq (length themes) 2)
-      (user-error "Can only toggle between two themes"))
-    (if (eq (car custom-enabled-themes) one)
-        (ef-themes--load-theme two)
-      (ef-themes--load-theme one))))
+  (if-let* ((themes (ef-themes--toggle-theme-p))
+            (one (car themes))
+            (two (cadr themes)))
+      (if (eq (car custom-enabled-themes) one)
+          (ef-themes--load-theme two)
+        (ef-themes--load-theme one))
+    (ef-themes--load-theme
+     (ef-themes--select-prompt
+      (concat "Set two `ef-themes-to-toggle'; "
+              "switching to theme selection for now: ")))))
 
 (defun ef-themes--minus-current (&optional variant)
   "Return list of Ef themes minus the current one.
@@ -401,8 +411,11 @@ prompts with completion for either `light' or `dark'."
   (interactive
    (list
     (when current-prefix-arg
-      (intern (completing-read "Random choice of Ef themes VARIANT: "
-                               '(light dark) nil t)))))
+      (intern (cadr (read-multiple-choice
+                     "Variant"
+                     '((?d "dark" "Load a random dark theme")
+                       (?l "light" "Load a random light theme"))
+                     "Limit the variation themes to select."))))))
   (let* ((themes (ef-themes--minus-current variant))
          (n (random (length themes)))
          (pick (nth n themes)))
@@ -521,37 +534,42 @@ Helper function for `ef-themes-preview-colors'."
     `(ef-themes-key-binding ((,c :inherit (bold ef-themes-fixed-pitch) :foreground ,keybind)))
     `(ef-themes-ui-variable-pitch ((,c ,@(ef-themes--variable-pitch-ui))))
 ;;;; all basic faces
-    `(default ((,c :background ,bg-main :foreground ,fg-main)))
-    `(cursor ((,c :background ,cursor)))
-    `(vertical-border ((,c :foreground ,border)))
+;;;;; absolute essentials
     `(bold ((,c :weight bold)))
-    `(italic ((,c :slant italic)))
     `(bold-italic ((,c :inherit (bold italic))))
+    `(cursor ((,c :background ,cursor)))
+    `(default ((,c :background ,bg-main :foreground ,fg-main)))
+    `(italic ((,c :slant italic)))
     `(region ((,c :background ,bg-region)))
+    `(vertical-border ((,c :foreground ,border)))
+;;;;; all other basic faces
+    `(button ((,c :foreground ,link :underline ,border)))
     `(comint-highlight-input ((,c :inherit bold)))
-    `(comint-highlight-prompt ((,c :foreground ,accent-2)))
-    `(minibuffer-prompt ((,c :foreground ,accent-2)))
+    `(comint-highlight-prompt ((,c :inherit minibuffer-prompt)))
+    `(edmacro-label ((,c :inherit bold)))
     `(elisp-shorthand-font-lock-face ((,c :inherit italic)))
-    `(escape-glyph ((,c :foreground ,warning)))
     `(error ((,c :inherit bold :foreground ,err)))
-    `(success ((,c :inherit bold :foreground ,info)))
-    `(warning ((,c :inherit bold :foreground ,warning)))
+    `(escape-glyph ((,c :foreground ,warning)))
     `(fringe ((,c :background unspecified)))
     `(header-line ((,c :inherit ef-themes-ui-variable-pitch :background ,bg-dim)))
     `(header-line-highlight ((,c :inherit highlight)))
     `(help-argument-name ((,c :foreground ,accent-0)))
     `(help-key-binding ((,c :inherit bold :foreground ,keybind)))
     `(highlight ((,c :background ,bg-hover :foreground ,fg-intense)))
-    `(secondary-selection ((,c :background ,bg-hover-alt :foreground ,fg-intense)))
     `(hl-line ((,c :background ,bg-hl-line)))
-    `(button ((,c :foreground ,link :underline ,border)))
+    `(icon-button ((,c :box ,fg-dim :background ,bg-active :foreground ,fg-intense))) ; same as `custom-button'
     `(link ((,c :foreground ,link :underline ,border)))
     `(link-visited ((,c :foreground ,link-alt :underline ,border)))
+    `(minibuffer-prompt ((,c :foreground ,prompt)))
     `(pgtk-im-0 ((,c :inherit secondary-selection)))
+    `(read-multiple-choice-face ((,c :inherit warning :background ,bg-warning)))
     `(rectangle-preview ((,c :inherit secondary-selection)))
+    `(secondary-selection ((,c :background ,bg-hover-alt :foreground ,fg-intense)))
     `(shadow ((,c :foreground ,fg-dim)))
-    `(trailing-whitespace ((,c :background ,bg-red :foreground ,fg-intense)))
+    `(success ((,c :inherit bold :foreground ,info)))
     `(tooltip ((,c :background ,bg-alt :foreground ,fg-intense)))
+    `(trailing-whitespace ((,c :background ,bg-red :foreground ,fg-intense)))
+    `(warning ((,c :inherit bold :foreground ,warning)))
 ;;;; all-the-icons
     `(all-the-icons-blue ((,c :foreground ,blue-cooler)))
     `(all-the-icons-blue-alt ((,c :foreground ,blue-warmer)))
@@ -640,7 +658,7 @@ Helper function for `ef-themes-preview-colors'."
     `(bongo-filled-seek-bar ((,c :background ,bg-hover)))
     `(bongo-marked-track ((,c :inherit success :background ,bg-info)))
     `(bongo-marked-track-line ((,c :background ,bg-dim)))
-    `(bongo-played-track ((,c :strike-through t)))
+    `(bongo-played-track ((,c :inherit shadow :strike-through t)))
     `(bongo-track-length ((,c :inherit shadow)))
     `(bongo-track-title ((,c :foreground ,rainbow-1)))
     `(bongo-unfilled-seek-bar ((,c :background ,bg-dim)))
@@ -658,11 +676,11 @@ Helper function for `ef-themes-preview-colors'."
     `(holiday ((,c :background ,bg-dim :foreground ,accent-2)))
 ;;;; change-log and log-view (`vc-print-log' and `vc-print-root-log')
     `(change-log-acknowledgment ((,c :inherit shadow)))
-    `(change-log-conditionals ((,c :foreground ,preprocessor)))
+    `(change-log-conditionals ((,c :inherit error)))
     `(change-log-date ((,c :foreground ,date)))
-    `(change-log-email ((,c :foreground ,constant)))
+    `(change-log-email ((,c :foreground ,fg-alt)))
     `(change-log-file ((,c :inherit bold)))
-    `(change-log-function ((,c :foreground ,fnname)))
+    `(change-log-function ((,c :inherit warning)))
     `(change-log-list ((,c :inherit bold)))
     `(change-log-name ((,c :foreground ,name)))
     `(log-edit-header ((,c :inherit bold)))
@@ -670,12 +688,12 @@ Helper function for `ef-themes-preview-colors'."
     `(log-edit-unknown-header ((,c :inherit shadow)))
     `(log-view-commit-body (( )))
     `(log-view-file ((,c :inherit bold)))
-    `(log-view-message ((,c :foreground ,fg-dim)))
+    `(log-view-message ((,c :inherit shadow)))
 ;;;; company-mode
     `(company-echo-common ((,c :inherit bold :foreground ,accent-0)))
     `(company-preview ((,c :background ,bg-dim :foreground ,fg-dim)))
     `(company-preview-common ((,c :inherit company-echo-common)))
-    `(company-preview-search ((,c :inherit modus-themes-special-calm)))
+    `(company-preview-search ((,c :background ,bg-yellow :foreground ,fg-intense)))
     `(company-scrollbar-bg ((,c :background ,bg-active)))
     `(company-scrollbar-fg ((,c :background ,fg-main)))
     `(company-template-field ((,c :background ,bg-active :foreground ,fg-intense)))
@@ -694,9 +712,9 @@ Helper function for `ef-themes-preview-colors'."
     `(compilation-error ((,c :inherit error)))
     `(compilation-info ((,c :inherit bold :foreground ,name)))
     `(compilation-line-number ((,c :inherit shadow)))
-    `(compilation-mode-line-exit ((,c :inherit bold)))
-    `(compilation-mode-line-fail ((,c :inherit error)))
-    `(compilation-mode-line-run ((,c :inherit warning)))
+    `(compilation-mode-line-exit ((,c :inherit bold :foreground ,modeline-info)))
+    `(compilation-mode-line-fail ((,c :inherit bold :foreground ,modeline-err)))
+    `(compilation-mode-line-run ((,c :inherit bold :foreground ,modeline-warning)))
     `(compilation-warning ((,c :inherit warning)))
 ;;;; completions
     `(completions-annotations ((,c :inherit italic :foreground ,docstring)))
@@ -809,10 +827,43 @@ Helper function for `ef-themes-preview-colors'."
     `(diredfl-symlink ((,c :inherit dired-symlink)))
     `(diredfl-tagged-autofile-name ((,c :inherit (diredfl-autofile-name dired-marked))))
     `(diredfl-write-priv ((,c :foreground ,rainbow-2)))
+;;;; dirvish
+    `(dirvish-hl-line ((,c :background ,bg-hl-line)))
 ;;;; doom-modeline
-    ;; NOTE 2022-08-20: This is the only face that seems necessary.  All
-    ;; others inherit from basic faces.
     `(doom-modeline-bar ((,c :background ,bg-accent)))
+    `(doom-modeline-bar-inactive ((,c :background ,bg-alt)))
+    `(doom-modeline-battery-charging ((,c :foreground ,modeline-info)))
+    `(doom-modeline-battery-critical ((,c :underline t :foreground ,modeline-err)))
+    `(doom-modeline-battery-error ((,c :underline t :foreground ,modeline-err)))
+    `(doom-modeline-battery-full (( )))
+    `(doom-modeline-battery-warning ((,c :inherit bold :foreground ,modeline-warning)))
+    `(doom-modeline-buffer-file ((,c :inherit bold)))
+    `(doom-modeline-buffer-major-mode (( )))
+    `(doom-modeline-buffer-minor-mode (( )))
+    `(doom-modeline-buffer-modified ((,c :foreground ,modeline-err)))
+    `(doom-modeline-buffer-path (( )))
+    `(doom-modeline-evil-emacs-state ((,c :inherit italic)))
+    `(doom-modeline-evil-insert-state ((,c :foreground ,modeline-info)))
+    `(doom-modeline-evil-motion-state (( )))
+    `(doom-modeline-evil-normal-state (( )))
+    `(doom-modeline-evil-operator-state ((,c :inherit bold)))
+    `(doom-modeline-evil-replace-state ((,c :inherit bold :foreground ,modeline-err)))
+    `(doom-modeline-evil-visual-state ((,c :inherit bold :foreground ,modeline-warning)))
+    `(doom-modeline-info ((,c :inherit bold :foreground ,modeline-info)))
+    `(doom-modeline-input-method (( )))
+    `(doom-modeline-lsp-error ((,c :inherit bold-italic)))
+    `(doom-modeline-lsp-running (( )))
+    `(doom-modeline-lsp-success ((,c :inherit bold :foreground ,modeline-info)))
+    `(doom-modeline-lsp-warning ((,c :inherit bold :foreground ,modeline-warning)))
+    `(doom-modeline-notification ((,c :inherit mode-line-emphasis :foreground ,modeline-err)))
+    `(doom-modeline-project-dir (( )))
+    `(doom-modeline-project-parent-dir (( )))
+    `(doom-modeline-project-root-dir (( )))
+    `(doom-modeline-repl-success ((,c :inherit bold :foreground ,modeline-info)))
+    `(doom-modeline-repl-warning ((,c :inherit bold :foreground ,modeline-warning)))
+    `(doom-modeline-time (( )))
+    `(doom-modeline-urgent ((,c :inherit bold-italic :foreground ,modeline-err)))
+    `(doom-modeline-warning ((,c :inherit bold :foreground ,modeline-warning)))
 ;;;; ediff
     `(ediff-current-diff-A ((,c :inherit diff-removed)))
     `(ediff-current-diff-Ancestor ((,c :background ,bg-region))) ; TODO 2022-08-14: Needs review
@@ -913,13 +964,81 @@ Helper function for `ef-themes-preview-colors'."
     `(git-rebase-comment-heading  ((,c :inherit (bold font-lock-comment-face))))
     `(git-rebase-description ((,c :foreground ,fg-main)))
     `(git-rebase-hash ((,c :foreground ,constant)))
-;;;; gnus WORK-IN-PROGRESS
-    `(gnus-emphasis-highlight-words ((,c :background ,bg-alt :foreground ,warning)))
+;;;; gnus
+    `(gnus-button ((,c :inherit button)))
+    `(gnus-cite-1 ((,c :inherit message-cited-text-1)))
+    `(gnus-cite-2 ((,c :inherit message-cited-text-2)))
+    `(gnus-cite-3 ((,c :inherit message-cited-text-3)))
+    `(gnus-cite-4 ((,c :inherit message-cited-text-4)))
+    `(gnus-cite-5 ((,c :inherit message-cited-text-1)))
+    `(gnus-cite-6 ((,c :inherit message-cited-text-2)))
+    `(gnus-cite-7 ((,c :inherit message-cited-text-3)))
+    `(gnus-cite-8 ((,c :inherit message-cited-text-4)))
+    `(gnus-cite-9 ((,c :inherit message-cited-text-1)))
+    `(gnus-cite-10 ((,c :inherit message-cited-text-2)))
+    `(gnus-cite-11 ((,c :inherit message-cited-text-3)))
+    `(gnus-cite-attribution ((,c :inherit italic)))
+    `(gnus-emphasis-bold ((,c :inherit bold)))
+    `(gnus-emphasis-bold-italic ((,c :inherit bold-italic)))
+    `(gnus-emphasis-highlight-words ((,c :inherit warning)))
+    `(gnus-emphasis-italic ((,c :inherit italic)))
+    `(gnus-emphasis-underline-bold ((,c :inherit gnus-emphasis-bold :underline t)))
+    `(gnus-emphasis-underline-bold-italic ((,c :inherit gnus-emphasis-bold-italic :underline t)))
+    `(gnus-emphasis-underline-italic ((,c :inherit gnus-emphasis-italic :underline t)))
+    `(gnus-group-mail-1 ((,c :inherit bold :foreground ,rainbow-1)))
+    `(gnus-group-mail-1-empty ((,c :foreground ,rainbow-1)))
+    `(gnus-group-mail-2 ((,c :inherit bold :foreground ,rainbow-2)))
+    `(gnus-group-mail-2-empty ((,c :foreground ,rainbow-2)))
+    `(gnus-group-mail-3 ((,c :inherit bold :foreground ,rainbow-3)))
+    `(gnus-group-mail-3-empty ((,c :foreground ,rainbow-3)))
+    `(gnus-group-mail-low ((,c :inherit bold :foreground ,fg-alt)))
+    `(gnus-group-mail-low-empty ((,c :foreground ,fg-alt)))
+    `(gnus-group-news-1 ((,c :inherit bold :foreground ,rainbow-1)))
+    `(gnus-group-news-1-empty ((,c :foreground ,rainbow-1)))
+    `(gnus-group-news-2 ((,c :inherit bold :foreground ,rainbow-2)))
+    `(gnus-group-news-2-empty ((,c :foreground ,rainbow-2)))
+    `(gnus-group-news-3 ((,c :inherit bold :foreground ,rainbow-3)))
+    `(gnus-group-news-3-empty ((,c :foreground ,rainbow-3)))
+    `(gnus-group-news-4 ((,c :inherit bold :foreground ,rainbow-4)))
+    `(gnus-group-news-4-empty ((,c :foreground ,rainbow-4)))
+    `(gnus-group-news-5 ((,c :inherit bold :foreground ,rainbow-5)))
+    `(gnus-group-news-5-empty ((,c :foreground ,rainbow-5)))
+    `(gnus-group-news-6 ((,c :inherit bold :foreground ,rainbow-6)))
+    `(gnus-group-news-6-empty ((,c :foreground ,rainbow-6)))
+    `(gnus-group-news-low ((,c :inherit bold :foreground ,fg-alt)))
+    `(gnus-group-news-low-empty ((,c :foreground ,fg-alt)))
     `(gnus-header-content ((,c :inherit message-header-other)))
     `(gnus-header-from ((,c :inherit message-header-to :underline nil)))
     `(gnus-header-name ((,c :inherit message-header-name)))
     `(gnus-header-newsgroups ((,c :inherit message-header-newsgroups)))
     `(gnus-header-subject ((,c :inherit message-header-subject)))
+    `(gnus-server-agent ((,c :inherit bold)))
+    `(gnus-server-closed ((,c :inherit italic)))
+    `(gnus-server-cloud ((,c :inherit bold :foreground ,fg-alt)))
+    `(gnus-server-cloud-host ((,c :inherit bold :foreground ,fg-alt :underline t)))
+    `(gnus-server-denied ((,c :inherit error)))
+    `(gnus-server-offline ((,c :inherit shadow)))
+    `(gnus-server-opened ((,c :inherit success)))
+    `(gnus-summary-cancelled ((,c :background ,bg-warning :foreground ,warning :extend t)))
+    `(gnus-summary-high-ancient ((,c :inherit bold :foreground ,fg-alt)))
+    `(gnus-summary-high-read ((,c :inherit bold :foreground ,fg-dim)))
+    `(gnus-summary-high-ticked ((,c :inherit bold :foreground ,err)))
+    `(gnus-summary-high-undownloaded ((,c :inherit bold-italic :foreground ,warning)))
+    `(gnus-summary-high-unread ((,c :inherit bold)))
+    `(gnus-summary-low-ancient ((,c :inherit italic)))
+    `(gnus-summary-low-read ((,c :inherit (shadow italic))))
+    `(gnus-summary-low-ticked ((,c :inherit italic :foreground ,err)))
+    `(gnus-summary-low-undownloaded ((,c :inherit italic :foreground ,warning)))
+    `(gnus-summary-low-unread (( )))
+    `(gnus-summary-normal-ancient (( )))
+    `(gnus-summary-normal-read ((,c :inherit shadow)))
+    `(gnus-summary-normal-ticked ((,c :foreground ,err)))
+    `(gnus-summary-normal-undownloaded ((,c :foreground ,warning)))
+    `(gnus-summary-normal-unread (( )))
+    `(gnus-summary-selected ((,c :inherit highlight)))
+;;;; image-dired
+    `(image-dired-thumb-flagged ((,c :background ,err)))
+    `(image-dired-thumb-mark ((,c :background ,info)))
 ;;;; info
     `(Info-quoted ((,c :inherit ef-themes-fixed-pitch :foreground ,accent-0))) ; the capitalization is canonical
     `(info-header-node ((,c :inherit (shadow bold))))
@@ -942,6 +1061,19 @@ Helper function for `ef-themes-preview-colors'."
 ;;;; keycast
     `(keycast-command ((,c :inherit bold)))
     `(keycast-key ((,c :background ,bg-accent :foreground ,fg-accent)))
+;;;; lin
+    `(lin-blue ((,c :background ,bg-blue-subtle)))
+    `(lin-cyan ((,c :background ,bg-cyan-subtle)))
+    `(lin-green ((,c :background ,bg-green-subtle)))
+    `(lin-magenta ((,c :background ,bg-magenta-subtle)))
+    `(lin-red ((,c :background ,bg-red-subtle)))
+    `(lin-yellow ((,c :background ,bg-yellow-subtle)))
+    `(lin-blue-override-fg ((,c :background ,bg-blue-subtle :foreground ,fg-intense)))
+    `(lin-cyan-override-fg ((,c :background ,bg-cyan-subtle :foreground ,fg-intense)))
+    `(lin-green-override-fg ((,c :background ,bg-green-subtle :foreground ,fg-intense)))
+    `(lin-magenta-override-fg ((,c :background ,bg-magenta-subtle :foreground ,fg-intense)))
+    `(lin-red-override-fg ((,c :background ,bg-red-subtle :foreground ,fg-intense)))
+    `(lin-yellow-override-fg ((,c :background ,bg-yellow-subtle :foreground ,fg-intense)))
 ;;;; line numbers (display-line-numbers-mode and global variant)
     ;; We need to fall back to `default' otherwise line numbers do not
     ;; scale when using `text-scale-adjust'.
@@ -997,8 +1129,8 @@ Helper function for `ef-themes-preview-colors'."
     `(magit-log-author ((,c :foreground ,name)))
     `(magit-log-date ((,c :foreground ,date)))
     `(magit-log-graph ((,c :inherit shadow)))
-    `(magit-mode-line-process ((,c :inherit bold)))
-    `(magit-mode-line-process-error ((,c :inherit bold-italic)))
+    `(magit-mode-line-process ((,c :inherit bold :foreground ,modeline-info)))
+    `(magit-mode-line-process-error ((,c :inherit bold :foreground ,modeline-err)))
     `(magit-process-ng ((,c :inherit error)))
     `(magit-process-ok ((,c :inherit success)))
     `(magit-reflog-amend ((,c :inherit warning)))
@@ -1110,7 +1242,7 @@ Helper function for `ef-themes-preview-colors'."
     `(mode-line ((,c :inherit ef-themes-ui-variable-pitch :background ,bg-mode-line :foreground ,fg-mode-line)))
     `(mode-line-active ((,c :inherit mode-line)))
     `(mode-line-buffer-id ((,c :inherit bold)))
-    `(mode-line-emphasis ((,c :inherit bold-italic)))
+    `(mode-line-emphasis ((,c :inherit bold :foreground ,modeline-info)))
     `(mode-line-highlight ((,c :inherit highlight)))
     `(mode-line-inactive ((,c :inherit ef-themes-ui-variable-pitch :background ,bg-alt :foreground ,fg-dim)))
 ;;;; mu4e
@@ -1199,10 +1331,10 @@ Helper function for `ef-themes-preview-colors'."
     `(org-agenda-diary ((,c :inherit org-agenda-calendar-sexp)))
     `(org-agenda-dimmed-todo-face ((,c :inherit shadow)))
     `(org-agenda-done ((,c :inherit success)))
-    `(org-agenda-filter-category ((,c :inherit bold)))
-    `(org-agenda-filter-effort ((,c :inherit bold)))
-    `(org-agenda-filter-regexp ((,c :inherit bold)))
-    `(org-agenda-filter-tags ((,c :inherit bold)))
+    `(org-agenda-filter-category ((,c :inherit bold :foreground ,modeline-err)))
+    `(org-agenda-filter-effort ((,c :inherit bold :foreground ,modeline-err)))
+    `(org-agenda-filter-regexp ((,c :inherit bold :foreground ,modeline-err)))
+    `(org-agenda-filter-tags ((,c :inherit bold :foreground ,modeline-err)))
     `(org-agenda-restriction-lock ((,c :background ,bg-dim :foreground ,fg-dim)))
     `(org-agenda-structure ((,c :inherit ef-themes-heading-0)))
     `(org-agenda-structure-filter ((,c :inherit (warning org-agenda-structure))))
@@ -1248,7 +1380,7 @@ Helper function for `ef-themes-preview-colors'."
     `(org-macro ((,c :inherit ef-themes-fixed-pitch :foreground ,accent-2)))
     `(org-meta-line ((,c :inherit (shadow ef-themes-fixed-pitch))))
     `(org-mode-line-clock (( )))
-    `(org-mode-line-clock-overrun ((,c :inherit bold :foreground ,err)))
+    `(org-mode-line-clock-overrun ((,c :inherit bold :foreground ,modeline-err)))
     `(org-priority ((,c :foreground ,fg-alt)))
     `(org-property-value ((,c :inherit ef-themes-fixed-pitch :foreground ,fg-alt)))
     `(org-quote ((,c :inherit org-block)))
@@ -1314,6 +1446,15 @@ Helper function for `ef-themes-preview-colors'."
     `(package-status-installed ((,c :foreground ,fg-alt)))
     `(package-status-new ((,c :inherit success)))
     `(package-status-unsigned ((,c :inherit error)))
+;;;; pulsar
+    `(pulsar-blue ((,c :background ,bg-blue-subtle)))
+    `(pulsar-cyan ((,c :background ,bg-cyan-subtle)))
+    `(pulsar-green ((,c :background ,bg-green-subtle)))
+    `(pulsar-magenta ((,c :background ,bg-magenta-subtle)))
+    `(pulsar-red ((,c :background ,bg-red-subtle)))
+    `(pulsar-yellow ((,c :background ,bg-yellow-subtle)))
+;;;; pulse
+    `(pulse-highlight-start-face ((,c :background ,bg-blue-subtle)))
 ;;;; rainbow-delimiters
     `(rainbow-delimiters-base-error-face ((,c :inherit (bold rainbow-delimiters-mismatched-face))))
     `(rainbow-delimiters-base-face    ((,c :foreground ,rainbow-0)))
@@ -1333,15 +1474,18 @@ Helper function for `ef-themes-preview-colors'."
     `(rcirc-dim-nick ((,c :inherit shadow)))
     `(rcirc-monospace-text ((,c :inherit fixed-pitch)))
     `(rcirc-my-nick ((,c :inherit bold :foreground ,accent-1)))
-    `(rcirc-nick-in-message ((,c :inherit warning)))
-    `(rcirc-nick-in-message-full-line ((,c :inherit italic)))
+    `(rcirc-nick-in-message ((,c :inherit rcirc-my-nick)))
+    `(rcirc-nick-in-message-full-line ((,c :inherit rcirc-my-nick)))
     `(rcirc-other-nick ((,c :inherit bold :foreground ,accent-0)))
     `(rcirc-prompt ((,c :inherit minibuffer-prompt)))
-    `(rcirc-server ((,c :inherit shadow)))
+    `(rcirc-server ((,c :inherit font-lock-comment-face)))
     `(rcirc-timestamp ((,c :foreground ,date)))
-    `(rcirc-track-keyword ((,c :inherit bold)))
-    `(rcirc-track-nick ((,c :inherit warning)))
+    `(rcirc-track-keyword ((,c :inherit bold :foreground ,modeline-warning)))
+    `(rcirc-track-nick ((,c :inherit rcirc-my-nick)))
     `(rcirc-url ((,c :inherit link)))
+;;;; recursion-indicator
+    `(recursion-indicator-general ((,c :foreground ,modeline-err)))
+    `(recursion-indicator-minibuffer ((,c :foreground ,modeline-info)))
 ;;;; regexp-builder (re-builder)
     `(reb-match-0 ((,c :background ,bg-cyan :foreground ,fg-intense)))
     `(reb-match-1 ((,c :background ,bg-magenta :foreground ,fg-intense)))
@@ -1360,6 +1504,12 @@ Helper function for `ef-themes-preview-colors'."
     `(ruler-mode-margins ((,c :inherit ruler-mode-default :foreground ,bg-main)))
     `(ruler-mode-pad ((,c :inherit ruler-mode-default :background ,bg-alt :foreground ,fg-dim)))
     `(ruler-mode-tab-stop ((,c :inherit ruler-mode-default :foreground ,yellow)))
+;;;; selectrum
+    `(selectrum-completion-annotation ((,c :inherit completions-annotations)))
+    `(selectrum-completion-docsig ((,c :inherit completions-annotations)))
+    `(selectrum-current-candidate ((,c :background ,bg-completion)))
+    `(selectrum-group-title ((,c :inherit bold :foreground ,name)))
+    `(selectrum-mouse-highlight ((,c :inherit highlight)))
 ;;;; show-paren-mode
     `(show-paren-match ((,c :background ,bg-paren :foreground ,fg-intense)))
     `(show-paren-match-expression ((,c :background ,bg-alt)))
@@ -1400,6 +1550,10 @@ Helper function for `ef-themes-preview-colors'."
     `(tab-line-tab-inactive ((,c :box (:line-width -2 :color ,bg-active) :background ,bg-active)))
     `(tab-line-tab-inactive-alternate ((,c :inherit tab-line-tab-inactive :foreground ,fg-alt)))
     `(tab-line-tab-modified ((,c :foreground ,warning)))
+;;;; tempel
+    `(tempel-default ((,c :inherit italic :background ,bg-alt :foreground ,fg-alt)))
+    `(tempel-field ((,c :background ,bg-info :foreground ,info)))
+    `(tempel-form ((,c :background ,bg-err :foreground ,err)))
 ;;;; term
     `(term ((,c :background ,bg-main :foreground ,fg-main)))
     `(term-bold ((,c :inherit bold)))
