@@ -1,4 +1,4 @@
-;;; ef-winter-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-winter-theme.el --- Legible dark theme with magenta, purple, fawn, teal colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-winter "Legible dark theme.")
+  (deftheme ef-winter "Legible dark theme with magenta, purple, fawn, teal colors.")
 
   (defconst ef-winter-palette
     '(;; Basic tones
@@ -85,6 +85,13 @@
       (bg-magenta  "#c040cf")
       (bg-cyan     "#2270be")
 
+      (bg-red-subtle      "#6a002a")
+      (bg-green-subtle    "#00422a")
+      (bg-yellow-subtle   "#5a3000")
+      (bg-blue-subtle     "#242679")
+      (bg-magenta-subtle  "#50105a")
+      (bg-cyan-subtle     "#004065")
+
       ;; Diffs
       (bg-added          "#002d1f")
       (bg-added-faint    "#001f18")
@@ -129,6 +136,10 @@
       (cursor        "#ff6ff0")
       (fg-intense    "#ffffff")
 
+      (modeline-err     "#ff9fbf")
+      (modeline-warning "#ddb300")
+      (modeline-info    "#40e0af")
+
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
@@ -139,6 +150,7 @@
       (date cyan-cooler)
       (name magenta)
       (keybind cyan-cooler)
+      (prompt magenta-warmer)
 
       (builtin magenta-warmer)
       (comment yellow-faint)
